# Frequently Asked Questions

## How do I know if watchmaker has installed?

There are several ways to validate that watchmaker has been installed on your
system. The simplest method is to run the command `watchmaker --help`. If it
displays the cli help page, watchmaker is installed.

## What do I do if watchmaker failed to install?

First, review the installation documentation provided with the watchmaker
package. If `pip` is not working as your primary installation process you can
attempt to install the package by cloning the repo of watchmaker.

```
python setup.py install
```

## How do I know if watchmaker has completed without errors?

By default, watchmaker will reboot the system after a sucessful execution.
Therefore, if the system reboots, watchmaker executed successfully. After the
reboot, the logs should be checked for errors. If anything fails, watchmaker
will suppress the reboot. (The `--no-reboot` flag can be used to suppress the
reboot even after a successful execution.)

You can also test the watchmaker exit code programmatically. If watchmaker
fails, it will return a non-zero exit code. If watchmaker completes
successfully, it will return an exit code of zero. You would typically pass the
`--no-reboot` flag if you intend to test the exit code and determine what to do
from there.

## What do I do if watchmaker failed to complete or completes with errors?

Start by checking the logs generated by watchmaker. The logs are stored in the
directory specified by the `--log-dir` argument. Search the log for entries
that have `[ERROR]`, this will give you a starting point to begin
troubleshooting. Also, if a salt state failed, look for the pattern
`Result: False`. If it is not an obvious or simple issue, feel free to create
an issue on the watchmaker github page. If there is a salt_call.debug.log in
the watchmaker log directory, you can look for `[ERROR]` messages in there as
well. However, this log file can be very noisy and a message with the error
label may not be related to the error you are encountering.

## Does watchmaker support Enterprise Linux 7?

Watchmaker is supported on RedHat 7 and CentOS 7. However, there may be issues
intermittently with the salt formulas as they are actively being developed.
